@@ -12,16 +12,18 @@ DESCRIPTION = "A web connected digital light sensor measuring the intensity of a
 def main():
     parser = argparse.ArgumentParser(description=DESCRIPTION)
     parser.add_argument('--command', metavar='command', required=True, type=str, help='the command. Supported commands are: listen (run the webthing service), register (register and starts the webthing service as a systemd unit, deregister (deregisters the systemd unit), log (prints the log)')
+    parser.add_argument('--hostname', metavar='hostname', required=True, type=str, help='the hostname of the webthing serivce')
     parser.add_argument('--port', metavar='port', required=True, type=int, help='the port of the webthing serivce')
     parser.add_argument('--gpio', metavar='gpio', required=False, type=int, help='the gpio number wired to the device')
+    parser.add_argument('--name', metavar='name', required=False, type=str, default="", help='the name')
     args = parser.parse_args()
 
     if args.command == 'listen':
-        print("running " + PACKAGENAME + " on port " + str(args.port) + "/gpio " + str(args.gpio))
-        run_server(int(args.port), int(args.gpio), DESCRIPTION)
+        print("running " + PACKAGENAME + " on p" + args.hostname + "/" + str(args.port) + " (gpio " + str(args.gpio) + ")")
+        run_server(args.hostname, int(args.port), int(args.gpio), args.name, DESCRIPTION)
     elif args.command == 'register':
-        print("register " + PACKAGENAME + " on port " + str(args.port) + "/gpio " + str(args.gpio) + " and starting it")
-        register(PACKAGENAME, ENTRY_POINT, int(args.port), int(args.gpio))
+        print("register " + PACKAGENAME + " on " + args.hostname + "/" + str(args.port) + " (gpio " + str(args.gpio) + ") and starting it")
+        register(PACKAGENAME, ENTRY_POINT, args.hostname,int(args.port), args.name, int(args.gpio))
     elif args.command == 'deregister':
         deregister(PACKAGENAME, int(args.port))
     elif args.command == 'log':
